Utilities
*********

This section shows general objects and helper functions that are used with this package.

Custom Waveform
===============

You can define custom waveforms by using the :class:`balderhub.waveform.lib.utils.CustomNonPeriodicWaveform` and
:class:`balderhub.waveform.lib.utils.CustomPeriodicWaveform` objects.


.. autoclass:: balderhub.waveform.lib.utils.waveforms.CustomNonPeriodicWaveform
    :members:

.. autoclass:: balderhub.waveform.lib.utils.waveforms.CustomPeriodicWaveform
    :members:


Common Waveform Classes
=======================

.. autoclass:: balderhub.waveform.lib.utils.waveforms.common.CardiacWaveform
    :members:

.. autoclass:: balderhub.waveform.lib.utils.waveforms.common.CosineWaveform
    :members:

.. autoclass:: balderhub.waveform.lib.utils.waveforms.common.SineWaveform
    :members:

.. autoclass:: balderhub.waveform.lib.utils.waveforms.common.DCWaveform
    :members:


Base Classes
============


.. autoclass:: balderhub.waveform.lib.utils.waveforms.AbstractWaveform
    :members:

.. autoclass:: balderhub.waveform.lib.utils.waveforms.BaseNonPeriodicWaveform
    :members:

.. autoclass:: balderhub.waveform.lib.utils.waveforms.BasePeriodicWaveform
    :members:
